@@ -167,10 +167,13 @@ class SInfoTable:
         for column in self.table_columns:
             table.add_column(column["label"], justify="right", no_wrap=True)
         table.add_column("SBATCH", justify="left")
+        colors_index = 0
         for row in self.dataframe.to_records():
+            if colors_index == len(colors):
+                colors_index = 0
             t_row = []
             if row["queue"] not in queue_colors:
-                queue_colors[row["queue"]] = colors.pop()
+                queue_colors[row["queue"]] = colors[colors_index]
             queue = row["queue"]
             constraint = row["constraint"]
             cpus = row["cpu"]
@@ -184,5 +187,6 @@ class SInfoTable:
                 f"[{color}]#SBATCH --partition={queue}\n#SBATCH --constraint={constraint}\n#SBATCH -c={vcpus}"
             )
             table.add_row(*t_row)
+            colors_index = colors_index + 1
 
         return table
